import { EsbuildTransformOptions, Plugin } from "vite";
import type { Config as SvgrConfig } from "@svgr/core";
export default function (options?: {
    /**
     * If "include" predicate is present, only passing paths will be processed
     * @param path E.g "C:/path/to/my-svg.svg"
     * @returns Whether given path should be processed by the plugin or not
     */
    include?: (path: string) => boolean;
    /**
     * If "exclude" predicate is present, every path excluding passing paths will be processed
     * @param path E.g "C:/path/to/my-svg.svg"
     * @returns Whether given path should be discarded or processed by the plugin
     */
    exclude?: (path: string) => boolean;
    componentLoaderOptions?: {
        /**
         * Options used while running SVGR on the original svg code/asset
         */
        svgrConfig?: SvgrConfig;
        /**
         * Options used to generate import code with given SVGR output
         */
        esbuildConfig?: EsbuildTransformOptions;
    };
}): Plugin;
